@@ -118,7 +118,7 @@ class Browser:
 
 pyi_non_kw_methods = """\
     def get_timeout(self, timeout: Union[timedelta, None]) -> float: ...
-    def convert_timeout(self, timeout: Union[timedelta, float]) -> float: ...
+    def convert_timeout(self, timeout: Union[timedelta, float], to_ms: bool = True) -> float: ...
     def millisecs_to_timestr(self, timeout: float)  -> str: ...
 
 """
